@@ -64,6 +64,7 @@ def decrypt_dtc_code(code):
         dig2 = str(obd_sensors.hex_to_int(current[1]))
         dig3 = str(obd_sensors.hex_to_int(current[2]))
         dig4 = str(obd_sensors.hex_to_int(current[3]))
+
         dtc.append(type+dig1+dig2+dig3+dig4)
         current = current[4:]
     return dtc
@@ -81,7 +82,7 @@ class OBDPort:
          to       = SERTIMEOUT
          self.ELMver = "Unknown"
          self.State = 1 #state SERIAL is 1 connected, 0 disconnected (connection failed)
-         print self.State
+         #print self.State
          self._notify_window=_notify_window
          wx.PostEvent(self._notify_window, DebugEvent([1,"Opening interface (serial port)"]))                
 
@@ -117,10 +118,10 @@ class OBDPort:
              wx.PostEvent(self._notify_window, DebugEvent([2,"ate0 response:" + self.get_result()]))
 
              self.send_command("0100")
-             time.sleep(0.3)
+             time.sleep(0.1)
              ready = self.get_result()
              print ready
-             time.sleep(5.0)
+             time.sleep(1.0)
              wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response1:" + ready]))
 
 #UNABLE TO CONNECT
@@ -128,7 +129,7 @@ class OBDPort:
 
 
              if ready=="SEARCHING...":
-                time.sleep(2.0)
+                time.sleep(1.2)
 
              if ready=="BUSINIT: ...OK":
                 ready=self.get_result()
@@ -167,7 +168,7 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.3)
+             time.sleep(0.2)
              self.port.flushOutput()
              self.port.flushInput()
              for c in cmd:
@@ -228,7 +229,7 @@ class OBDPort:
      # get sensor value from command
      def get_sensor_value(self,sensor):
          """Internal use only: not a public interface"""
-   
+
          cmd = sensor.cmd
          self.send_command(cmd)
          data = self.get_result()
@@ -245,12 +246,15 @@ class OBDPort:
 
      # return string of sensor name and value from sensor index
      def sensor(self , sensor_index):
+
+         print "def sensor: "+ str(sensor_index)
+
          """Returns 3-tuple of given sensors. 3-tuple consists of
          (Sensor Name (string), Sensor Value (string), Sensor Unit (string) ) """
          sensor = obd_sensors.SENSORS[sensor_index]
          r = self.get_sensor_value(sensor)
          print "Sensor name: " + sensor.name
-         print "Sensor unit: " + sensor.unit
+         #print "Sensor unit: " + sensor.unit
          return (sensor.name,r, sensor.unit)
 
      def sensor_names(self):
@@ -331,12 +335,18 @@ class OBDPort:
                 break
                    
               DTCStr=dtcLetters[(val&0xC000)>14]+str((val&0x3000)>>12)+str(val&0x0fff)
+
+              #M se restituisce codici a 6 cifre invece che ha 5
+              if len(DTCStr)>5:
+                 DTCStr = DTCStr[0]+DTCStr[2:]
+                 print DTCStr
+
               DTCCodes.append(["Passive",DTCStr])
               
           return DTCCodes
               
      def clear_dtc(self):
-         print "clear_dtc"
+         print "def clear_dtc"
          """Clears all DTCs and freeze frame data"""
          self.send_command(CLEAR_DTC_COMMAND)     
          r = self.get_result()
