@@ -156,14 +156,26 @@ class MyApp(wx.App):
             if self.port.State==0: #Cant open serial port
                 return None
 
-            self.active   = []
+            self.active = []
+
+            self.supp   = self.port.sensor(0)[1] #read supported PIDS1x
+            self.supp1  = self.port.sensor(32)[1] #read supported PIDS2x
+            self.supp2  = self.port.sensor(64)[1] #read supported PIDS3x
+
+            print "self.supp  " + (self.supp)
+            print "self.supp1 " + (self.supp1)
+            print "self.supp2 " + (self.supp2)
+
+            #self.supp = self.supp+self.supp1
+            self.supp = str(self.supp+self.supp1+self.supp2)
+
+            print "self.sup f: " + self.supp
 
-            self.supp     = self.port.sensor(0)[1] #read supported PIDS
             self.active.append(1); #PID 0 is always supported
-            
+         
             wx.PostEvent(self._notify_window, ResultEvent([0,0,"X"]))
             wx.PostEvent(self._notify_window, DebugEvent([1,"Communication initialized..."]))
-            
+
             for i in range(1, len(self.supp)):
                 if self.supp[i-1] == "1": #put X in coloum if PID is supported
                     self.active.append(1)
@@ -171,6 +183,7 @@ class MyApp(wx.App):
                 else:
                     self.active.append(0)
                     wx.PostEvent(self._notify_window, ResultEvent([i,0,""]))
+
             return "OK"
         
 
@@ -209,9 +222,15 @@ class MyApp(wx.App):
                 
                 elif curstate==2: #show sensor tab
                   for i in range(3, len(self.active)):
+
+
+                      #print "active pid "+str(self.active)
+
+
                       if self.active[i]:
                           s = self.port.sensor(i)
                           wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1], s[2])]))
+
                       if self._notify_window.ThreadControl==666:
                           break
                 elif curstate==3: #show DTC tab
@@ -340,8 +359,8 @@ class MyApp(wx.App):
                                   wx.LC_SINGLE_SEL)
      
 
-        self.sensors.InsertColumn(0, "Supported",width=120)
-        self.sensors.InsertColumn(1, "Sensor",format=wx.LIST_FORMAT_CENTER, width=370)
+        self.sensors.InsertColumn(0, "S.",width=40)
+        self.sensors.InsertColumn(1, "Sensor",format=wx.LIST_FORMAT_CENTER, width=400)
         self.sensors.InsertColumn(2, "Value")
         for i in range(0, len(obd_io.obd_sensors.SENSORS)):
             s = obd_io.obd_sensors.SENSORS[i].name
@@ -426,7 +445,7 @@ class MyApp(wx.App):
           self.RECONNATTEMPTS=self.config.getint("pyOBD","RECONNATTEMPTS")
           self.SERTIMEOUT=self.config.getint("pyOBD","SERTIMEOUT")
         
-        frame = wx.Frame(None, -1, "pyOBD-II")
+        frame = wx.Frame(None, -1, "pyOBD-II for n900")
         self.frame=frame
 
         EVT_RESULT(self,self.OnResult,EVT_RESULT_ID)
@@ -437,9 +456,10 @@ class MyApp(wx.App):
         
         # Main notebook frames
         self.nb = wx.Notebook(frame, -1, style = wx.NB_TOP)
-        
+        self.nb.SetFont(wx.FFont(17, wx.DEFAULT)) 
+
         self.status = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
-        self.status.InsertColumn(0, "Description",width=200)
+        self.status.InsertColumn(0, "Description",width=280)
         self.status.InsertColumn(1, "Value")
         self.status.Append(["Link State","Disconnnected"]);
         self.status.Append(["Protocol","---"]);
@@ -452,7 +472,7 @@ class MyApp(wx.App):
         self.nb.AddPage(self.status, "Status")
         
         self.OBDTests = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
-        self.OBDTests.InsertColumn(0, "Description",width=250)
+        self.OBDTests.InsertColumn(0, "Description",width=280)
         self.OBDTests.InsertColumn(1, "Value")
         self.nb.AddPage(self.OBDTests, "Tests")
                 
@@ -540,15 +560,16 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """Adapted to work with n900 by m750
+        Text = """pyobd-0.9.2-10beta
+Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
 Note: pyOBD does not recognize all the 
 error codes, especially those personalized 
-by the cars factories. 
+by cars factories. 
 Eventually you can edit the file: 
   /home/opt/obd2_codes.py 
-and add that particular error code. 
+to add this error codes. 
 
 """
 
@@ -558,7 +579,7 @@ and add that particular error code.
 
     
     def OnHelpAbout(self,event): #todo about box
-        Text = """PyOBD is an automotive OBD2 diagnosting application using ELM237 cable.
+        Text = """PyOBD is an automotive OBD2 diagnosting app. using ELM237 cable.
 (C) 2008-2009 SeCons Ltd.
 (C) 2004 Charles Donour Sizemore
 www.obdtester.com  www.secons.com
@@ -566,7 +587,8 @@ PyOBD is free software; you can
 redistribute it and/or modify it under the 
 terms of the GNU General Public License 
 as published by the Free SW Foundation; 
-either version 2 of the License, or (at your option) any later version.   
+either version 2 of the License, or any 
+later version.   
 
 """
 
@@ -624,9 +646,6 @@ either version 2 of the License, or (at your option) any later version.
         #w = sensorProduce()
         #w.ws.PostEvent(self._notify_window, StatusEvent([0,1,"Disconnected"]))
 
-
-
-
         time.sleep(0.1)
         self.btname = " "
         self.ThreadControl=666
@@ -747,7 +766,7 @@ either version 2 of the License, or (at your option) any later version.
                print " -Found device: %s (%s)" % (btname, btaddr)
 
                try:
-                  if len(btname) > 2:
+                  if len(btname) >= 2:
                     found=1
                     # Use the first device it finds that matches name
                     print '    Found BT SPP dev'
@@ -780,9 +799,8 @@ either version 2 of the License, or (at your option) any later version.
                   else:
                     print "NOT FOUND"
                except:
-                    found=0
-                    print "error"
-                    os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"BT Error, please retry"')
+                    if found==0:
+                       os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"BT Error, please retry"')
 
              break
 
